Search.setIndex({"alltitles": {"Contents:": [[6, null], [7, null], [8, null]], "Description": [[6, "description"], [7, "description"]], "IOHandler": [[0, "iohandler"]], "ImplicitMount": [[1, "implicitmount"]], "Indices and tables": [[8, "indices-and-tables"]], "PyTorch Integration": [[6, "pytorch-integration"]], "RemotePathDataLoader": [[2, "remotepathdataloader"]], "RemotePathDataset": [[3, "remotepathdataset"]], "RemotePathIterator": [[4, "remotepathiterator"]], "SFTP Backend": [[7, "sftp-backend"]], "User Configuration": [[5, "user-configuration"]], "Welcome to PyRemoteData\u2019s documentation!": [[8, "welcome-to-pyremotedata-s-documentation"]]}, "docnames": ["IOHandler", "ImplicitMount", "RemotePathDataLoader", "RemotePathDataset", "RemotePathIterator", "config", "dataloader", "implicit_mount", "index"], "envversion": {"sphinx": 61, "sphinx.domains.c": 3, "sphinx.domains.changeset": 1, "sphinx.domains.citation": 1, "sphinx.domains.cpp": 9, "sphinx.domains.index": 1, "sphinx.domains.javascript": 3, "sphinx.domains.math": 2, "sphinx.domains.python": 4, "sphinx.domains.rst": 2, "sphinx.domains.std": 2}, "filenames": ["IOHandler.rst", "ImplicitMount.rst", "RemotePathDataLoader.rst", "RemotePathDataset.rst", "RemotePathIterator.rst", "config.rst", "dataloader.rst", "implicit_mount.rst", "index.rst"], "indexentries": {}, "objects": {}, "objnames": {}, "objtypes": {}, "terms": {"It": 8, "The": 8, "access": 8, "ani": 8, "applic": 8, "backend": 8, "bandwidth": 8, "been": 8, "can": 8, "class": 6, "configur": 8, "data": [6, 8], "develop": 8, "download": 8, "facilit": 8, "from": 6, "ha": 8, "high": 8, "i": 8, "implicitmount": 7, "includ": 6, "index": 8, "integr": 8, "internet": 8, "iohandl": 7, "iterabledataload": 6, "iterabledataset": 6, "latenc": 8, "learn": 8, "load": 6, "machin": 8, "manag": 8, "modul": 8, "over": 8, "packag": 8, "page": 8, "primarili": 8, "progress": 8, "protocol": 8, "pyremotedata": 6, "python": 8, "pytorch": 8, "remot": [6, 8], "remotepathdataload": 6, "remotepathdataset": 6, "remotepathiter": [6, 7], "requir": 8, "search": 8, "server": [6, 8], "sftp": [6, 8], "situat": 8, "support": 8, "through": 6, "throughput": 8, "transfer": 8, "us": 8, "user": 8, "work": 8}, "titles": ["IOHandler", "ImplicitMount", "RemotePathDataLoader", "RemotePathDataset", "RemotePathIterator", "User Configuration", "PyTorch Integration", "SFTP Backend", "Welcome to PyRemoteData\u2019s documentation!"], "titleterms": {"": 8, "backend": 7, "configur": 5, "content": [6, 7, 8], "descript": [6, 7], "document": 8, "implicitmount": 1, "indic": 8, "integr": 6, "iohandl": 0, "pyremotedata": 8, "pytorch": 6, "remotepathdataload": 2, "remotepathdataset": 3, "remotepathiter": 4, "sftp": 7, "tabl": 8, "user": 5, "welcom": 8}})